"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var mask_model_function_1 = require("../mask-model.function");
describe("maskModel", function () {
    var password = "1234";
    var model = { password: password };
    it("should return the passed value no metadata are passed", function () {
        var result = mask_model_function_1.maskModel({ model: model });
        expect(result).toEqual(model);
    });
    it("should proxy null or undefined", function () {
        var result = mask_model_function_1.maskModel({
            model: null
        });
        expect(result).toBeNull();
    });
    it("should call maskAttribute for included attributes", function () {
        spyOn(mask_model_function_1.maskModelConfig, "maskAttribute").and.callThrough();
        var modelMetadata = {};
        mask_model_function_1.maskModel({
            model: model,
            modelMetadata: modelMetadata
        });
        expect(mask_model_function_1.maskModelConfig.maskAttribute).toHaveBeenCalledWith({
            value: password,
            attributeMetadata: undefined
        });
    });
    it("should call maskModel for included models", function () {
        spyOn(mask_model_function_1.maskModelConfig, "maskModel").and.callThrough();
        var modelMetadata = {};
        mask_model_function_1.maskModel({
            model: { nested: model },
            modelMetadata: modelMetadata
        });
        expect(mask_model_function_1.maskModelConfig.maskModel).toHaveBeenCalledWith({
            model: model,
            modelMetadata: undefined
        }, mask_model_function_1.maskModelConfig);
    });
    it("should call maskArray for included models", function () {
        spyOn(mask_model_function_1.maskModelConfig, "maskArray").and.callThrough();
        var modelMetadata = {};
        mask_model_function_1.maskModel({
            model: { nested: [model] },
            modelMetadata: modelMetadata
        });
        expect(mask_model_function_1.maskModelConfig.maskArray).toHaveBeenCalledWith({
            array: [model],
            arrayMetadata: undefined
        }, mask_model_function_1.maskModelConfig);
    });
    it("should mask secret attributes in the passed model", function () {
        var model = {
            shouldBeSecret: "1234",
            regular: "regular",
            items: [{
                    shouldBeSecret: "5678",
                    regular: "regular"
                }],
            nested: {
                shouldBeSecret: "90",
                regular: "regular"
            }
        };
        var modelMetadata = {
            attributes: {
                shouldBeSecret: {
                    isSecret: true
                },
                items: {
                    item: {
                        attributes: {
                            shouldBeSecret: {
                                isSecret: true
                            }
                        }
                    }
                },
                nested: {
                    attributes: {
                        shouldBeSecret: {
                            isSecret: true
                        }
                    }
                }
            }
        };
        var result = mask_model_function_1.maskModel({
            model: model,
            modelMetadata: modelMetadata
        });
        var expectedResult = {
            shouldBeSecret: "<secret>",
            regular: "regular",
            items: [{
                    shouldBeSecret: "<secret>",
                    regular: "regular"
                }],
            nested: {
                shouldBeSecret: "<secret>",
                regular: "regular"
            }
        };
        expect(result).toEqual(expectedResult);
    });
});
