"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var resolve_masked_model_function_1 = require("../resolve-masked-model.function");
describe("resolveMaskedAttribute", function () {
    var value = "test";
    it("should return a null or undefined value", function () {
        var result = resolve_masked_model_function_1.resolveMaskedAttribute({
            value: null
        });
        expect(result).toBeNull();
    });
    it("should return the passed value if there's no referenceValue", function () {
        var result = resolve_masked_model_function_1.resolveMaskedAttribute({
            value: value,
            referenceValue: null
        });
        expect(result).toBe(value);
    });
    it("should return the passed value if there's no attributeMetadata", function () {
        var result = resolve_masked_model_function_1.resolveMaskedAttribute({
            value: value,
            referenceValue: value
        });
        expect(result).toBe(value);
    });
    it("should return the passed value if attributeMetadata do not declare it as secret", function () {
        var result = resolve_masked_model_function_1.resolveMaskedAttribute({
            value: value,
            referenceValue: value
        });
        expect(result).toBe(value);
    });
    it("should return the passed value if its value is not \"<secret>\"", function () {
        var attributeMetadata = {};
        var result = resolve_masked_model_function_1.resolveMaskedAttribute({
            value: value,
            referenceValue: value,
            attributeMetadata: attributeMetadata
        });
        expect(result).toBe(value);
    });
    it("should return the passed referenceValue if the passed value is \"<secret>\"", function () {
        var attributeMetadata = {
            isSecret: true
        };
        var result = resolve_masked_model_function_1.resolveMaskedAttribute({
            value: "<secret>",
            referenceValue: value,
            attributeMetadata: attributeMetadata
        });
        expect(result).toBe(value);
    });
    it("should return \"<missing-secret>\" if the passed value is \"<secret>\" and referenceValue is unset ", function () {
        var attributeMetadata = {
            isSecret: true
        };
        var result = resolve_masked_model_function_1.resolveMaskedAttribute({
            value: "<secret>",
            referenceValue: null,
            attributeMetadata: attributeMetadata
        });
        expect(result).toBe("<missing-secret>");
    });
});
