"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var resolve_masked_model_function_1 = require("../resolve-masked-model.function");
var mask_model_function_1 = require("../mask-model.function");
describe("resolveMaskedModel", function () {
    var attribute = "test";
    var model = { attribute: attribute };
    it("should return a null or undefined value", function () {
        var result = resolve_masked_model_function_1.resolveMaskedModel({
            model: null
        });
        expect(result).toBeNull();
    });
    it("should return the passed model if there's no referenceModel", function () {
        var result = resolve_masked_model_function_1.resolveMaskedModel({
            model: model,
            referenceModel: null
        });
        expect(result).toBe(model);
    });
    it("should return the passed model if there's no modelMetadata", function () {
        var result = resolve_masked_model_function_1.resolveMaskedModel({
            model: model,
            referenceModel: model
        });
        expect(result).toBe(model);
    });
    it("should call resolveMaskedAttribute for included attributes", function () {
        spyOn(resolve_masked_model_function_1.resolvedMaskedModelConfig, "resolveMaskedAttribute").and.callThrough();
        var modelMetadata = {};
        resolve_masked_model_function_1.resolveMaskedModel({
            model: model,
            referenceModel: model,
            modelMetadata: modelMetadata
        });
        expect(resolve_masked_model_function_1.resolvedMaskedModelConfig.resolveMaskedAttribute).toHaveBeenCalledWith({
            value: attribute,
            referenceValue: attribute,
            attributeMetadata: undefined
        });
    });
    it("should call resolveMaskedArray for included arrays", function () {
        spyOn(resolve_masked_model_function_1.resolvedMaskedModelConfig, "resolveMaskedArray").and.callThrough();
        var modelWithArray = {
            items: [model]
        };
        var modelMetadata = {};
        resolve_masked_model_function_1.resolveMaskedModel({
            model: modelWithArray,
            referenceModel: modelWithArray,
            modelMetadata: modelMetadata
        });
        expect(resolve_masked_model_function_1.resolvedMaskedModelConfig.resolveMaskedArray).toHaveBeenCalledWith({
            array: modelWithArray.items,
            referenceArray: modelWithArray.items,
            arrayMetadata: undefined
        }, resolve_masked_model_function_1.resolvedMaskedModelConfig);
    });
    it("should call resolveMaskedModel for included models", function () {
        spyOn(resolve_masked_model_function_1.resolvedMaskedModelConfig, "resolveMaskedModel").and.callThrough();
        var modelWithNested = {
            nested: model
        };
        var modelMetadata = {};
        resolve_masked_model_function_1.resolveMaskedModel({
            model: modelWithNested,
            referenceModel: modelWithNested,
            modelMetadata: modelMetadata
        });
        expect(resolve_masked_model_function_1.resolvedMaskedModelConfig.resolveMaskedModel).toHaveBeenCalledWith({
            model: modelWithNested.nested,
            referenceModel: modelWithNested.nested,
            modelMetadata: undefined
        }, resolve_masked_model_function_1.resolvedMaskedModelConfig);
    });
    it("should be the counter operation to maskModel", function () {
        var referenceModel = {
            shouldBeSecret: "1234",
            regular: "regular",
            items: [{
                    shouldBeSecret: "5678",
                    regular: "regular"
                }],
            nested: {
                shouldBeSecret: "90",
                regular: "regular"
            }
        };
        var modelMetadata = {
            attributes: {
                shouldBeSecret: {
                    isSecret: true
                },
                items: {
                    item: {
                        attributes: {
                            shouldBeSecret: {
                                isSecret: true
                            }
                        }
                    }
                },
                nested: {
                    attributes: {
                        shouldBeSecret: {
                            isSecret: true
                        }
                    }
                }
            }
        };
        var model = mask_model_function_1.maskModel({
            model: referenceModel,
            modelMetadata: modelMetadata
        });
        var result = resolve_masked_model_function_1.resolveMaskedModel({
            model: model,
            referenceModel: referenceModel,
            modelMetadata: modelMetadata
        });
        expect(result).toEqual(referenceModel);
    });
});
