"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteMaskedSecretAttributesFromArray = exports.deleteMaskedAttributesFromArrayConfig = exports.deleteMaskedSecretAttributes = exports.deleteSecretAttributesConfig = void 0;
var is_null_or_undefined_function_1 = require("../validation/is-null-or-undefined.function");
exports.deleteSecretAttributesConfig = {
    deleteMaskedSecretAttributesFromArray: deleteMaskedSecretAttributesFromArray,
    deleteMaskedSecretAttributes: deleteMaskedSecretAttributes
};
function deleteMaskedSecretAttributes(payload, config) {
    if (config === void 0) { config = exports.deleteSecretAttributesConfig; }
    var model = payload.model;
    var metadata = payload.modelMetadata;
    if (is_null_or_undefined_function_1.isNullOrUndefined(model))
        return model;
    if (is_null_or_undefined_function_1.isNullOrUndefined(metadata))
        return model;
    return Object.keys(model).reduce(function (result, attributeKey) {
        var resolvedMetadata = metadata.attributes ? metadata.attributes[attributeKey] : undefined;
        var attributeValue = model[attributeKey];
        if (resolvedMetadata && resolvedMetadata.isSecret && (attributeValue === "<secret>" || attributeValue === "<missing-secret>"))
            return result;
        if (Array.isArray(model[attributeKey])) {
            attributeValue = config.deleteMaskedSecretAttributesFromArray({
                array: model[attributeKey], arrayMetadata: resolvedMetadata
            }, config);
        }
        else if (typeof model[attributeKey] === "object") {
            attributeValue = config.deleteMaskedSecretAttributes({
                model: model[attributeKey], modelMetadata: resolvedMetadata
            }, config);
        }
        else {
            attributeValue = model[attributeKey];
        }
        result[attributeKey] = attributeValue;
        return result;
    }, {});
}
exports.deleteMaskedSecretAttributes = deleteMaskedSecretAttributes;
exports.deleteMaskedAttributesFromArrayConfig = {
    deleteMaskedSecretAttributesFromArray: deleteMaskedSecretAttributesFromArray,
    deleteMaskedSecretAttributes: deleteMaskedSecretAttributes
};
function deleteMaskedSecretAttributesFromArray(payload, config) {
    if (config === void 0) { config = exports.deleteMaskedAttributesFromArrayConfig; }
    var value = payload.array;
    var metadata = payload.arrayMetadata;
    if (is_null_or_undefined_function_1.isNullOrUndefined(value))
        return value;
    if (is_null_or_undefined_function_1.isNullOrUndefined(metadata))
        return value;
    return value.map(function (item) {
        if (Array.isArray(item)) {
            return config.deleteMaskedSecretAttributesFromArray({
                array: item,
                arrayMetadata: metadata.item
            }, config);
        }
        else if (typeof item === "object") {
            return config.deleteMaskedSecretAttributes({
                model: item,
                modelMetadata: metadata.item
            }, config);
        }
        else {
            return item;
        }
    });
}
exports.deleteMaskedSecretAttributesFromArray = deleteMaskedSecretAttributesFromArray;
