"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.maskArray = exports.maskArrayConfig = exports.maskModel = exports.maskModelConfig = exports.maskAttribute = void 0;
var is_null_or_undefined_function_1 = require("../validation/is-null-or-undefined.function");
var mask_secret_attribute_function_1 = require("./mask-secret-attribute.function");
function maskAttribute(payload) {
    var value = payload.value;
    var metadata = payload.attributeMetadata;
    if (is_null_or_undefined_function_1.isNullOrUndefined(value))
        return value;
    if (is_null_or_undefined_function_1.isNullOrUndefined(metadata))
        return value;
    if (metadata.isSecret && typeof value === "string")
        return mask_secret_attribute_function_1.maskSecretAttribute(value);
    return value;
}
exports.maskAttribute = maskAttribute;
exports.maskModelConfig = {
    maskArray: maskArray,
    maskModel: maskModel,
    maskAttribute: maskAttribute
};
function maskModel(payload, config) {
    if (config === void 0) { config = exports.maskModelConfig; }
    var model = payload.model;
    var metadata = payload.modelMetadata;
    if (is_null_or_undefined_function_1.isNullOrUndefined(model))
        return model;
    if (is_null_or_undefined_function_1.isNullOrUndefined(metadata))
        return model;
    return Object.keys(model).reduce(function (result, attributeKey) {
        var resolvedMetadata = metadata.attributes ? metadata.attributes[attributeKey] : undefined;
        var attributeValue;
        if (Array.isArray(model[attributeKey])) {
            attributeValue = config.maskArray({
                array: model[attributeKey], arrayMetadata: resolvedMetadata
            }, config);
        }
        else if (typeof model[attributeKey] === "object") {
            attributeValue = config.maskModel({
                model: model[attributeKey], modelMetadata: resolvedMetadata
            }, config);
        }
        else {
            attributeValue = config.maskAttribute({
                value: model[attributeKey], attributeMetadata: resolvedMetadata
            });
        }
        result[attributeKey] = attributeValue;
        return result;
    }, {});
}
exports.maskModel = maskModel;
exports.maskArrayConfig = {
    maskArray: maskArray,
    maskModel: maskModel,
    maskAttribute: maskAttribute
};
function maskArray(payload, config) {
    if (config === void 0) { config = exports.maskArrayConfig; }
    var value = payload.array;
    var metadata = payload.arrayMetadata;
    if (is_null_or_undefined_function_1.isNullOrUndefined(value))
        return value;
    if (is_null_or_undefined_function_1.isNullOrUndefined(metadata))
        return value;
    return value.map(function (item) {
        if (Array.isArray(item)) {
            return config.maskArray({
                array: item,
                arrayMetadata: metadata.item
            }, config);
        }
        else if (typeof item === "object") {
            return config.maskModel({
                model: item,
                modelMetadata: metadata.item
            }, config);
        }
        else {
            return config.maskAttribute({
                value: item,
                attributeMetadata: metadata.item
            });
        }
    });
}
exports.maskArray = maskArray;
