"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveMaskedArray = exports.resolvedMaskedArrayConfig = exports.resolveMaskedModel = exports.resolvedMaskedModelConfig = exports.resolveMaskedAttribute = void 0;
var is_null_or_undefined_function_1 = require("../validation/is-null-or-undefined.function");
function resolveMaskedAttribute(payload) {
    var value = payload.value;
    var referenceValue = payload.referenceValue;
    var attributeMetadata = payload.attributeMetadata;
    if (is_null_or_undefined_function_1.isNullOrUndefined(value))
        return value;
    if (is_null_or_undefined_function_1.isNullOrUndefined(attributeMetadata))
        return value;
    if (!attributeMetadata.isSecret)
        return value;
    if (value !== "<secret>")
        return value;
    if (value === "<secret>" && is_null_or_undefined_function_1.isNullOrUndefined(referenceValue))
        return "<missing-secret>";
    return referenceValue;
}
exports.resolveMaskedAttribute = resolveMaskedAttribute;
exports.resolvedMaskedModelConfig = {
    resolveMaskedAttribute: resolveMaskedAttribute,
    resolveMaskedModel: resolveMaskedModel,
    resolveMaskedArray: resolveMaskedArray
};
function resolveMaskedModel(payload, config) {
    if (config === void 0) { config = exports.resolvedMaskedModelConfig; }
    var model = payload.model;
    var referenceModel = payload.referenceModel;
    var modelMetadata = payload.modelMetadata;
    if (is_null_or_undefined_function_1.isNullOrUndefined(model))
        return model;
    if (is_null_or_undefined_function_1.isNullOrUndefined(referenceModel))
        return model;
    if (is_null_or_undefined_function_1.isNullOrUndefined(modelMetadata))
        return model;
    return Object.keys(model).reduce(function (result, attributeKey) {
        var resolvedMetadata = modelMetadata.attributes ? modelMetadata.attributes[attributeKey] : undefined;
        var attributeValue;
        if (Array.isArray(model[attributeKey])) {
            attributeValue = config.resolveMaskedArray({
                array: model[attributeKey],
                referenceArray: referenceModel[attributeKey],
                arrayMetadata: resolvedMetadata
            }, config);
        }
        else if (typeof model[attributeKey] === "object") {
            attributeValue = config.resolveMaskedModel({
                model: model[attributeKey],
                referenceModel: referenceModel[attributeKey],
                modelMetadata: resolvedMetadata
            }, config);
        }
        else {
            attributeValue = config.resolveMaskedAttribute({
                value: model[attributeKey],
                referenceValue: referenceModel[attributeKey],
                attributeMetadata: resolvedMetadata
            });
        }
        result[attributeKey] = attributeValue;
        return result;
    }, {});
}
exports.resolveMaskedModel = resolveMaskedModel;
exports.resolvedMaskedArrayConfig = {
    resolveMaskedAttribute: resolveMaskedAttribute,
    resolveMaskedModel: resolveMaskedModel,
    resolveMaskedArray: resolveMaskedArray
};
function resolveMaskedArray(payload, config) {
    if (config === void 0) { config = exports.resolvedMaskedArrayConfig; }
    var array = payload.array;
    var referenceArray = payload.referenceArray;
    var arrayMetadata = payload.arrayMetadata;
    if (is_null_or_undefined_function_1.isNullOrUndefined(array))
        return array;
    if (is_null_or_undefined_function_1.isNullOrUndefined(referenceArray))
        return array;
    if (is_null_or_undefined_function_1.isNullOrUndefined(arrayMetadata))
        return array;
    return array.map(function (item, index) {
        if (Array.isArray(item)) {
            return config.resolveMaskedArray({
                array: item,
                referenceArray: referenceArray[index],
                arrayMetadata: arrayMetadata.item
            }, config);
        }
        else if (typeof item === "object") {
            return config.resolveMaskedModel({
                model: item,
                referenceModel: referenceArray[index],
                modelMetadata: arrayMetadata.item
            }, config);
        }
        else {
            return config.resolveMaskedAttribute({
                value: item,
                referenceValue: referenceArray[index],
                attributeMetadata: arrayMetadata.item
            });
        }
    });
}
exports.resolveMaskedArray = resolveMaskedArray;
