"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var create_missing_attribute_value_error_function_1 = require("../create-missing-attribute-value-error.function");
var create_min_violation_error_function_1 = require("../create-min-violation-error.function");
var create_max_violation_error_function_1 = require("../create-max-violation-error.function");
var validate_model_function_1 = require("../validate-model.function");
describe("validateArray", function () {
    var array = [];
    var attributePath = "key";
    var modelId = "modelId";
    var modelType = "modelType";
    var validResult = { isValid: true };
    it("should return a valid result if no metadata are passed.", function () {
        var result = validate_model_function_1.validateArray({ array: array, attributePath: attributePath, modelId: modelId, modelType: modelType });
        expect(result).toEqual(validResult);
    });
    /**
     * General
     */
    it("should return an error if no model is passed but the attribute is required.", function () {
        var nullValue = null;
        var result = validate_model_function_1.validateArray({
            array: nullValue,
            attributePath: attributePath,
            arrayMetadata: { isRequired: true },
            modelId: modelId, modelType: modelType
        });
        var expectedError = create_missing_attribute_value_error_function_1.createMissingAttributeValueError({ value: nullValue, attributePath: attributePath, modelId: modelId, modelType: modelType });
        expect(result.isValid).toBeFalsy();
        expect(result.errors).toContainEqual(expectedError);
    });
    it("should return an error if an array model's length is below the allowed minimum.", function () {
        var arrayValue = [{}, {}, {}, {}];
        var min = 5;
        var result = validate_model_function_1.validateArray({
            array: arrayValue,
            attributePath: attributePath, arrayMetadata: { min: min }, modelId: modelId, modelType: modelType
        });
        var expectedError = create_min_violation_error_function_1.createMinViolationError({
            value: arrayValue.length,
            attributePath: attributePath,
            min: min,
            modelId: modelId,
            modelType: modelType
        });
        expect(result.isValid).toBeFalsy();
        expect(result.errors).toContainEqual(expectedError);
    });
    it("should return an error if an array model's length is above the allowed maximum.", function () {
        var arrayValue = [{}, {}, {}, {}];
        var max = 3;
        var result = validate_model_function_1.validateArray({
            array: arrayValue,
            attributePath: attributePath, arrayMetadata: { max: max }, modelId: modelId, modelType: modelType
        });
        var expectedError = create_max_violation_error_function_1.createMaxViolationError({
            value: arrayValue.length,
            attributePath: attributePath,
            max: max,
            modelId: modelId,
            modelType: modelType
        });
        expect(result.isValid).toBeFalsy();
        expect(result.errors).toContainEqual(expectedError);
    });
    /**
     * item
     */
    it("should call validateArray for array items", function () {
        spyOn(validate_model_function_1.validateArrayConfig, "validateArray").and.callThrough();
        var item = { label: "abcd" };
        var arrayValue = [[item]];
        var arrayMetadata = {
            item: {
                item: {
                    attributes: {
                        label: { max: 4 }
                    }
                }
            }
        };
        validate_model_function_1.validateArray({
            array: arrayValue,
            attributePath: attributePath, arrayMetadata: arrayMetadata, modelId: modelId, modelType: modelType
        });
        expect(validate_model_function_1.validateArrayConfig.validateArray).toHaveBeenCalledWith({
            array: arrayValue[0],
            attributePath: attributePath + ".0",
            arrayMetadata: arrayMetadata.item,
            modelId: modelId, modelType: modelType
        }, validate_model_function_1.validateArrayConfig);
    });
    it("should call validateModel for object items", function () {
        spyOn(validate_model_function_1.validateArrayConfig, "validateModel").and.callThrough();
        var item = { label: "abcd" };
        var arrayValue = [item];
        var arrayMetadata = {
            item: {
                attributes: {
                    label: { max: 4 }
                }
            }
        };
        validate_model_function_1.validateArray({
            array: arrayValue,
            attributePath: attributePath, arrayMetadata: arrayMetadata, modelId: modelId, modelType: modelType
        });
        expect(validate_model_function_1.validateArrayConfig.validateModel).toHaveBeenCalledWith({
            model: item,
            attributePath: attributePath + ".0",
            modelMetadata: arrayMetadata.item,
            modelId: modelId, modelType: modelType
        }, validate_model_function_1.validateArrayConfig);
    });
    it("should call validateAttribute for attribute items", function () {
        spyOn(validate_model_function_1.validateArrayConfig, "validateAttribute").and.callThrough();
        var item = "abcd";
        var arrayValue = [item];
        var arrayMetadata = { item: { max: 4 } };
        validate_model_function_1.validateArray({ array: arrayValue, attributePath: attributePath, arrayMetadata: arrayMetadata, modelId: modelId, modelType: modelType });
        expect(validate_model_function_1.validateArrayConfig.validateAttribute).toHaveBeenCalledWith({
            value: item,
            attributePath: attributePath + ".0",
            attributeMetadata: arrayMetadata.item,
            modelId: modelId, modelType: modelType
        });
    });
});
