"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var create_missing_attribute_value_error_function_1 = require("../create-missing-attribute-value-error.function");
var create_min_violation_error_function_1 = require("../create-min-violation-error.function");
var create_max_violation_error_function_1 = require("../create-max-violation-error.function");
var validate_model_function_1 = require("../validate-model.function");
describe("validateAttribute", function () {
    var value = "Test";
    var attributePath = "key";
    var modelId = "modelId";
    var modelType = "modelType";
    var validResult = { isValid: true };
    it("should return a valid result if no metadata are passed.", function () {
        var result = validate_model_function_1.validateAttribute({ value: value, attributePath: attributePath, modelId: modelId, modelType: modelType });
        expect(result).toEqual(validResult);
    });
    it("should return an error if no model is passed but the attribute is required.", function () {
        var nullValue = null;
        var result = validate_model_function_1.validateAttribute({
            value: nullValue,
            attributePath: attributePath,
            attributeMetadata: { isRequired: true },
            modelId: modelId, modelType: modelType
        });
        var expectedError = create_missing_attribute_value_error_function_1.createMissingAttributeValueError({ value: nullValue, attributePath: attributePath, modelId: modelId, modelType: modelType });
        expect(result.isValid).toBeFalsy();
        expect(result.errors).toContainEqual(expectedError);
    });
    /**
     * min
     */
    it("should return an error if a number model's value is below the allowed minimum.", function () {
        var numberValue = 4;
        var min = 5;
        var result = validate_model_function_1.validateAttribute({
            value: numberValue,
            attributePath: attributePath, attributeMetadata: { min: min }, modelId: modelId, modelType: modelType
        });
        var expectedError = create_min_violation_error_function_1.createMinViolationError({ value: numberValue, attributePath: attributePath, min: min, modelId: modelId, modelType: modelType });
        expect(result.isValid).toBeFalsy();
        expect(result.errors).toContainEqual(expectedError);
    });
    it("should return an error if a string model's length is below the allowed minimum.", function () {
        var stringValue = "abcd";
        var min = 5;
        var result = validate_model_function_1.validateAttribute({
            value: stringValue,
            attributePath: attributePath, attributeMetadata: { min: min }, modelId: modelId, modelType: modelType
        });
        var expectedError = create_min_violation_error_function_1.createMinViolationError({
            value: stringValue.length,
            attributePath: attributePath,
            min: min,
            modelId: modelId,
            modelType: modelType
        });
        expect(result.isValid).toBeFalsy();
        expect(result.errors).toContainEqual(expectedError);
    });
    it("should return an error if an array model's length is below the allowed minimum.", function () {
        var arrayValue = [{}, {}, {}, {}];
        var min = 5;
        var result = validate_model_function_1.validateAttribute({
            value: arrayValue,
            attributePath: attributePath, attributeMetadata: { min: min }, modelId: modelId, modelType: modelType
        });
        var expectedError = create_min_violation_error_function_1.createMinViolationError({
            value: arrayValue.length,
            attributePath: attributePath,
            min: min,
            modelId: modelId,
            modelType: modelType
        });
        expect(result.isValid).toBeFalsy();
        expect(result.errors).toContainEqual(expectedError);
    });
    /**
     * max
     */
    it("should return an error if a number model's value is above the allowed maximum.", function () {
        var numberValue = 4;
        var max = 3;
        var result = validate_model_function_1.validateAttribute({
            value: numberValue,
            attributePath: attributePath, attributeMetadata: { max: max }, modelId: modelId, modelType: modelType
        });
        var expectedError = create_max_violation_error_function_1.createMaxViolationError({ value: numberValue, attributePath: attributePath, max: max, modelId: modelId, modelType: modelType });
        expect(result.isValid).toBeFalsy();
        expect(result.errors).toContainEqual(expectedError);
    });
    it("should return an error if a string model's length is above the allowed maximum.", function () {
        var stringValue = "abcd";
        var max = 3;
        var result = validate_model_function_1.validateAttribute({
            value: stringValue,
            attributePath: attributePath, attributeMetadata: { max: max }, modelId: modelId, modelType: modelType
        });
        var expectedError = create_max_violation_error_function_1.createMaxViolationError({
            value: stringValue.length,
            attributePath: attributePath,
            max: max,
            modelId: modelId,
            modelType: modelType
        });
        expect(result.isValid).toBeFalsy();
        expect(result.errors).toContainEqual(expectedError);
    });
    it("should return an error if an array model's length is above the allowed maximum.", function () {
        var arrayValue = [{}, {}, {}, {}];
        var max = 3;
        var result = validate_model_function_1.validateAttribute({
            value: arrayValue,
            attributePath: attributePath, attributeMetadata: { max: max }, modelId: modelId, modelType: modelType
        });
        var expectedError = create_max_violation_error_function_1.createMaxViolationError({
            value: arrayValue.length,
            attributePath: attributePath,
            max: max,
            modelId: modelId,
            modelType: modelType
        });
        expect(result.isValid).toBeFalsy();
        expect(result.errors).toContainEqual(expectedError);
    });
});
