"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var validate_model_function_1 = require("../validate-model.function");
var create_missing_attribute_value_error_function_1 = require("../create-missing-attribute-value-error.function");
describe("validateModel", function () {
    var attributePath = "key";
    var validResult = { isValid: true };
    var modelId = "modelId";
    var modelType = "modelType";
    it("should return a valid result if no metadata are passed", function () {
        var model = {};
        var result = validate_model_function_1.validateModel({ model: model, attributePath: attributePath, modelId: modelId, modelType: modelType });
        expect(result).toEqual(validResult);
    });
    it("should return a valid result if the passed metadata have no attributes", function () {
        var model = {};
        var result = validate_model_function_1.validateModel({ model: model, attributePath: attributePath, modelMetadata: {}, modelId: modelId, modelType: modelType });
        expect(result).toEqual(validResult);
    });
    /**
     * General
     */
    it("should return an error if no model is passed but it is required.", function () {
        var nullValue = null;
        var result = validate_model_function_1.validateModel({
            model: nullValue,
            attributePath: attributePath,
            modelMetadata: { isRequired: true },
            modelId: modelId, modelType: modelType
        });
        var expectedError = create_missing_attribute_value_error_function_1.createMissingAttributeValueError({ value: nullValue, attributePath: attributePath, modelId: modelId, modelType: modelType });
        expect(result.isValid).toBeFalsy();
        expect(result.errors).toContainEqual(expectedError);
    });
    it("should call validateArray for array attributes", function () {
        spyOn(validate_model_function_1.validateModelConfig, "validateArray").and.callThrough();
        var model = { nested: [] };
        var modelMetadata = {
            attributes: { nested: {} }
        };
        validate_model_function_1.validateModel({ model: model, attributePath: attributePath, modelMetadata: modelMetadata, modelId: modelId, modelType: modelType });
        expect(validate_model_function_1.validateModelConfig.validateArray).toHaveBeenCalledWith({
            array: model.nested,
            attributePath: attributePath + ".nested",
            arrayMetadata: modelMetadata.attributes.nested,
            modelId: modelId, modelType: modelType
        }, validate_model_function_1.validateModelConfig);
    });
    it("should call validateModel for model attributes", function () {
        spyOn(validate_model_function_1.validateModelConfig, "validateModel").and.callThrough();
        var model = { nested: { label: "abcd" } };
        var modelMetadata = {
            attributes: { nested: {} }
        };
        validate_model_function_1.validateModel({ model: model, attributePath: attributePath, modelMetadata: modelMetadata, modelId: modelId, modelType: modelType });
        expect(validate_model_function_1.validateModelConfig.validateModel).toHaveBeenCalledWith({
            model: model.nested,
            attributePath: attributePath + ".nested",
            modelMetadata: modelMetadata.attributes.nested,
            modelId: modelId, modelType: modelType
        }, validate_model_function_1.validateModelConfig);
    });
    it("should call validateAttribute for primitive attributes", function () {
        spyOn(validate_model_function_1.validateModelConfig, "validateAttribute").and.callThrough();
        var model = { label: "abcd" };
        var modelMetadata = {
            attributes: { label: {} }
        };
        validate_model_function_1.validateModel({ model: model, attributePath: attributePath, modelMetadata: modelMetadata, modelId: modelId, modelType: modelType });
        expect(validate_model_function_1.validateModelConfig.validateAttribute).toHaveBeenCalledWith({
            value: model.label,
            attributePath: attributePath + ".label",
            attributeMetadata: modelMetadata.attributes.label,
            modelId: modelId, modelType: modelType
        });
    });
});
