"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateArray = exports.validateArrayConfig = void 0;
var create_missing_attribute_value_error_function_1 = require("./create-missing-attribute-value-error.function");
var create_max_violation_error_function_1 = require("./create-max-violation-error.function");
var create_min_violation_error_function_1 = require("./create-min-violation-error.function");
var validate_model_function_1 = require("./validate-model.function");
var validate_attribute_function_1 = require("./validate-attribute.function");
var is_null_or_undefined_function_1 = require("./is-null-or-undefined.function");
var not_null_or_undefined_function_1 = require("./not-null-or-undefined.function");
var create_empty_model_validation_result_function_1 = require("./create-empty-model-validation-result.function");
exports.validateArrayConfig = {
    validateArray: validateArray,
    validateModel: validate_model_function_1.validateModel,
    validateAttribute: validate_attribute_function_1.validateAttribute
};
function validateArray(payload, config) {
    if (config === void 0) { config = exports.validateArrayConfig; }
    var value = payload.array;
    var metadata = payload.arrayMetadata;
    var attributePath = payload.attributePath || "";
    var modelId = payload.modelId;
    var modelType = payload.modelType;
    if (is_null_or_undefined_function_1.isNullOrUndefined(metadata))
        return { isValid: true };
    var result = create_empty_model_validation_result_function_1.createEmptyModelValidationResult();
    if (is_null_or_undefined_function_1.isNullOrUndefined(value)) {
        if (metadata.isRequired) {
            result.isValid = false;
            result.errors.push(create_missing_attribute_value_error_function_1.createMissingAttributeValueError({
                value: value, attributePath: attributePath, modelId: modelId, modelType: modelType
            }));
        }
    }
    else {
        if (not_null_or_undefined_function_1.notNullOrUndefined(metadata.max) && value.length > metadata.max) {
            result.isValid = false;
            result.errors.push(create_max_violation_error_function_1.createMaxViolationError({
                value: value.length, max: metadata.max,
                attributePath: attributePath, modelId: modelId, modelType: modelType
            }));
        }
        if (not_null_or_undefined_function_1.notNullOrUndefined(metadata.min) && value.length < metadata.min) {
            result.isValid = false;
            result.errors.push(create_min_violation_error_function_1.createMinViolationError({
                value: value.length, min: metadata.min,
                attributePath: attributePath, modelId: modelId, modelType: modelType
            }));
        }
        value.forEach(function (item, index) {
            var childAttributePath = attributePath + "." + index;
            var r;
            if (Array.isArray(item)) {
                r = config.validateArray({
                    array: item,
                    attributePath: childAttributePath,
                    arrayMetadata: metadata.item,
                    modelId: modelId, modelType: modelType
                }, config);
            }
            else if (typeof item === "object") {
                r = config.validateModel({
                    model: item,
                    attributePath: childAttributePath,
                    modelMetadata: metadata.item,
                    modelId: modelId, modelType: modelType
                }, config);
            }
            else {
                r = config.validateAttribute({
                    value: item,
                    attributePath: childAttributePath,
                    attributeMetadata: metadata.item,
                    modelId: modelId, modelType: modelType
                });
            }
            if (!r.isValid) {
                result.isValid = false;
                result.errors = result.errors.concat(r.errors);
            }
        });
    }
    if (result.isValid)
        delete result.errors;
    return result;
}
exports.validateArray = validateArray;
