"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateAttribute = void 0;
var create_missing_attribute_value_error_function_1 = require("./create-missing-attribute-value-error.function");
var create_min_violation_error_function_1 = require("./create-min-violation-error.function");
var create_max_violation_error_function_1 = require("./create-max-violation-error.function");
var is_null_or_undefined_function_1 = require("./is-null-or-undefined.function");
var not_null_or_undefined_function_1 = require("./not-null-or-undefined.function");
var create_empty_model_validation_result_function_1 = require("./create-empty-model-validation-result.function");
function validateAttribute(payload) {
    var value = payload.value;
    var attributePath = payload.attributePath;
    var metadata = payload.attributeMetadata;
    var modelId = payload.modelId;
    var modelType = payload.modelType;
    if (is_null_or_undefined_function_1.isNullOrUndefined(metadata))
        return { isValid: true };
    var result = create_empty_model_validation_result_function_1.createEmptyModelValidationResult();
    if (is_null_or_undefined_function_1.isNullOrUndefined(value)) {
        if (metadata.isRequired) {
            result.isValid = false;
            result.errors.push(create_missing_attribute_value_error_function_1.createMissingAttributeValueError({
                value: value, attributePath: attributePath, modelId: modelId, modelType: modelType
            }));
        }
    }
    else {
        var resolvedValue = void 0;
        if (typeof value === "number")
            resolvedValue = value;
        else if (typeof value === "string")
            resolvedValue = value.length;
        else if (Array.isArray(value))
            resolvedValue = value.length;
        if (not_null_or_undefined_function_1.notNullOrUndefined(metadata.max) && resolvedValue > metadata.max) {
            result.isValid = false;
            result.errors.push(create_max_violation_error_function_1.createMaxViolationError({
                value: resolvedValue, max: metadata.max,
                attributePath: attributePath, modelId: modelId, modelType: modelType
            }));
        }
        if (not_null_or_undefined_function_1.notNullOrUndefined(metadata.min) && resolvedValue < metadata.min) {
            result.isValid = false;
            result.errors.push(create_min_violation_error_function_1.createMinViolationError({
                value: resolvedValue, min: metadata.min,
                attributePath: attributePath, modelId: modelId, modelType: modelType
            }));
        }
    }
    if (result.isValid)
        delete result.errors;
    return result;
}
exports.validateAttribute = validateAttribute;
